@@ -10,6 +10,9 @@ from docudevs.api.cases.create_case import asyncio_detailed as create_case_async
 from docudevs.api.cases.get_case import asyncio_detailed as get_case_async
 from docudevs.api.cases.list_cases import asyncio_detailed as list_cases_async
 from docudevs.api.cases.upload_case_document import asyncio_detailed as upload_case_document_async
+from docudevs.api.batch.create_batch import asyncio_detailed as create_batch_async
+from docudevs.api.batch.process_batch import asyncio_detailed as process_batch_async
+from docudevs.api.batch.upload_batch_document import asyncio_detailed as upload_batch_document_async
 from docudevs.api.configuration import (
     delete_configuration,
     get_configuration,
@@ -419,6 +422,150 @@ class DocuDevsClient:
             raise Exception(f"Error processing document: {content_str}")
         return guid
 
+    # --------------------------- Batch Processing Convenience ---------------------------
+    async def create_batch(self, max_concurrency: int | None = None) -> str:
+        """Create a new batch processing job using generated client.
+
+        Note: The generated CreateBatchBody requires orgId; server will infer from auth so we send a placeholder.
+        """
+        from docudevs.models.create_batch_body import CreateBatchBody
+        body = CreateBatchBody(org_id="placeholder", max_concurrency=max_concurrency if max_concurrency is not None else UNSET)
+        resp = await create_batch_async(client=self._client, body=body)
+        if resp.status_code != HTTPStatus.OK or not resp.parsed:
+            raise Exception(f"Error creating batch job: {getattr(resp,'content', b'').decode('utf-8','ignore') if hasattr(resp,'content') else resp}")
+        guid = getattr(resp.parsed, "job_guid", None) or getattr(resp.parsed, "jobGuid", None)
+        if not guid:
+            raise Exception("Batch creation response missing jobGuid")
+        return guid
+
+    async def upload_batch_document(
+        self,
+        batch_guid: str,
+        document,
+        mime_type: str,
+        file_name: str | None = None,
+    ) -> dict:
+        """Upload a single document into an existing batch job using generated client."""
+        from docudevs.models.upload_batch_document_body import UploadBatchDocumentBody
+        # Normalize to bytes
+        if isinstance(document, str) and not hasattr(document, "read"):
+            file_name = file_name or document.split("/")[-1]
+            with open(document, "rb") as f:
+                payload = f.read()
+        else:
+            if hasattr(document, "read"):
+                payload = document.read()  # type: ignore
+            else:
+                payload = document
+            file_name = file_name or "document"
+        file_obj = File(payload=payload, file_name=file_name, mime_type=mime_type)
+        body = UploadBatchDocumentBody(document=file_obj, org_id="placeholder")
+        resp = await upload_batch_document_async(guid=batch_guid, client=self._client, body=body)
+        if resp.status_code != HTTPStatus.OK or not resp.parsed:
+            raise Exception(f"Error uploading batch document: status={resp.status_code}")
+        # Return dict representation
+        parsed = resp.parsed
+        return {
+            "jobGuid": getattr(parsed, "job_guid", None) or getattr(parsed, "jobGuid", None),
+            "index": getattr(parsed, "index", None),
+            "totalDocuments": getattr(parsed, "total_documents", None) or getattr(parsed, "totalDocuments", None),
+        }
+
+    async def process_batch(
+        self,
+        batch_guid: str,
+        *,
+        prompt: str = "",
+        schema: str = "",
+        mime_type: str,
+        ocr: Optional[OcrType] = None,
+        barcodes: Optional[bool] = None,
+        llm: Optional[LlmType] = None,
+        extraction_mode: Optional[str] = None,
+        describe_figures: Optional[bool] = None,
+    ) -> str:
+        """Finalize and start processing a batch using generated client."""
+        if not mime_type:
+            raise ValueError("mime_type is required for batch processing")
+        from docudevs.models.process_batch_body import ProcessBatchBody
+        from docudevs.models.map_reduce_command import MapReduceCommand  # potential future reuse
+        # Normalize optional enums
+        ocr_enum = ocr if ocr is not None else UNSET
+        llm_enum = llm if llm is not None else UNSET
+        if extraction_mode is not None:
+            try:
+                from docudevs.models.extraction_mode import check_extraction_mode
+                extraction_mode_value = check_extraction_mode(extraction_mode)
+            except Exception:
+                raise ValueError("Invalid extraction_mode value; expected one of 'OCR','SIMPLE','STEPS'")
+        else:
+            extraction_mode_value = UNSET
+        body = ProcessBatchBody(
+            org_id="placeholder",
+            prompt=prompt if prompt else UNSET,
+            schema=schema if schema else UNSET,
+            mime_type=mime_type,
+            ocr=ocr_enum,
+            llm=llm_enum,
+            extraction_mode=extraction_mode_value,
+            barcodes=barcodes if barcodes is not None else UNSET,
+            describe_figures=describe_figures if describe_figures is not None else UNSET,
+        )
+        resp = await process_batch_async(guid=batch_guid, client=self._client, body=body)
+        if resp.status_code != HTTPStatus.OK or not resp.parsed:
+            raise Exception(f"Error initiating batch processing: status={resp.status_code}")
+        return batch_guid
+
+    async def schedule_batch(self, batch_guid: str) -> dict:
+        """Call the scheduling endpoint for a batch (concurrency-aware scheduling)."""
+        resp = await self._client._async_client.post(  # type: ignore[attr-defined]
+            f"/document/batch/{batch_guid}/schedule", json={}
+        )
+        if resp.status_code != HTTPStatus.OK:
+            raise Exception(f"Error scheduling batch: {resp.text}")
+        return resp.json() if hasattr(resp, "json") else {}
+
+    async def submit_and_process_batch(
+        self,
+        documents,
+        document_mime_type: str,
+        *,
+        prompt: str = "",
+        schema: str = "",
+        ocr: Optional[OcrType] = None,
+        barcodes: Optional[bool] = None,
+        llm: Optional[LlmType] = None,
+        extraction_mode: Optional[str] = None,
+        describe_figures: Optional[bool] = None,
+        max_concurrency: int | None = None,
+    ) -> str:
+        """High-level convenience to create a batch, upload multiple documents, and start processing.
+
+        Args:
+            documents: Iterable of paths, bytes, or file-like objects
+            document_mime_type: Shared MIME type for all documents
+            prompt, schema, ocr, barcodes, llm, extraction_mode, describe_figures: As per single doc helpers
+            max_concurrency: Optional concurrency parameter when creating batch
+
+        Returns:
+            The batch job GUID.
+        """
+        guid = await self.create_batch(max_concurrency=max_concurrency)
+        for doc in documents:
+            await self.upload_batch_document(guid, doc, document_mime_type)
+        await self.process_batch(
+            guid,
+            prompt=prompt,
+            schema=schema,
+            mime_type=document_mime_type,
+            ocr=ocr,
+            barcodes=barcodes,
+            llm=llm,
+            extraction_mode=extraction_mode,
+            describe_figures=describe_figures,
+        )
+        return guid
+
     async def process_document_with_configuration(self, guid: str, configuration: str):
         """Process a document using a named configuration.
 
@@ -438,6 +585,77 @@ class DocuDevsClient:
         """Get job result."""
         return await result.asyncio_detailed(client=self._client, uuid=uuid)
 
+    # --------------------------- New Result Format Helpers ---------------------------
+    async def result_json(self, uuid: str):
+        """Get job result explicitly as JSON via /job/result/{uuid}/json.
+
+        Falls back to legacy endpoint if the server responds 404 (older server) or 415 (non-JSON / markdown result).
+        Returns:
+            - If JSON: parsed JSON object (dict/list/etc) when possible, else raw text.
+            - If fallback due to markdown/plain: raw text string.
+        Raises:
+            Exception on unexpected non-2xx responses other than 404/415 fallback cases.
+        """
+        resp = await self._client._async_client.get(f"/job/result/{uuid}/json")  # type: ignore[attr-defined]
+        if resp.status_code == 200:
+            text = resp.text
+            try:
+                import json
+                return json.loads(text)
+            except Exception:
+                return text
+        if resp.status_code in (404, 415):  # fallback path (legacy or markdown/plain text)
+            legacy = await self.result(uuid)
+            if legacy.status_code == 200:
+                # Try parse JSON then fallback to text
+                try:
+                    import json
+                    return json.loads(legacy.content.decode("utf-8", errors="replace"))
+                except Exception:
+                    return legacy.content.decode("utf-8", errors="replace")
+            raise Exception(f"Legacy result fetch failed: {legacy.status_code}")
+        raise Exception(f"Unexpected status fetching JSON result: {resp.status_code} - {getattr(resp,'text','')}")
+
+    async def result_csv(self, uuid: str) -> str:
+        """Get job result as CSV via /job/result/{uuid}/csv.
+
+        Returns CSV text. If the server replies 415 (non-JSON content) a descriptive Exception is raised.
+        """
+        resp = await self._client._async_client.get(f"/job/result/{uuid}/csv")  # type: ignore[attr-defined]
+        if resp.status_code == 200:
+            return resp.text
+        if resp.status_code == 404:
+            raise FileNotFoundError(f"Result not found for job {uuid}")
+        if resp.status_code == 415:
+            raise Exception("Result is not JSON (markdown/plain); CSV export unsupported.")
+        raise Exception(f"Unexpected status fetching CSV result: {resp.status_code} - {getattr(resp,'text','')}")
+
+    async def result_excel(self, uuid: str, save_to: str | None = None) -> bytes:
+        """Get job result as Excel (XLSX) via /job/result/{uuid}/excel.
+
+        Args:
+            uuid: Job GUID
+            save_to: Optional path; if provided writes the binary content to this file.
+
+        Returns:
+            Raw XLSX bytes.
+        Raises:
+            - FileNotFoundError if 404
+            - Exception with message for 415 (non-JSON) or other non-2xx codes.
+        """
+        resp = await self._client._async_client.get(f"/job/result/{uuid}/excel")  # type: ignore[attr-defined]
+        if resp.status_code == 200:
+            data = resp.content
+            if save_to:
+                with open(save_to, "wb") as f:  # pragma: no cover (filesystem side effect)
+                    f.write(data)
+            return data
+        if resp.status_code == 404:
+            raise FileNotFoundError(f"Result not found for job {uuid}")
+        if resp.status_code == 415:
+            raise Exception("Result is not JSON (markdown/plain); Excel export unsupported.")
+        raise Exception(f"Unexpected status fetching Excel result: {resp.status_code}")
+
     async def status(self, guid: str):
         """Get job status."""
         return await status.asyncio_detailed(client=self._client, guid=guid)
@@ -944,20 +1162,22 @@ class DocuDevsClient:
             raise Exception(f"Error processing document with OCR: {content_str}")
         return guid
 
-    async def wait_until_ready(self, guid: str, timeout: int = 180, poll_interval: float = 5.0):
+    async def wait_until_ready(self, guid: str, timeout: int = 180, poll_interval: float = 5.0, result_format: str | None = None, excel_save_to: str | None = None):
         """Wait for a job to complete (by polling status) and then return the result.
 
         Args:
             guid: The job GUID to wait for
             timeout: Maximum time to wait in seconds (default: 180)
             poll_interval: Time between status checks in seconds (default: 5.0)
+            result_format: Optional explicit format: 'json', 'csv', 'excel'. None => legacy behavior (auto / raw).
+            excel_save_to: Optional path when requesting 'excel' to persist the file.
 
         Returns:
-            The job result once complete
+            Parsed JSON (dict/list) for json format, CSV string for csv, bytes for excel, or legacy parsed/simple namespace for None.
 
         Raises:
             TimeoutError: If the job doesn't complete within the timeout
-            Exception: If the job fails or errors occur
+            Exception: If the job fails or errors occur or unsupported format for content
         """
         start_time = time.time()
 
@@ -986,7 +1206,15 @@ class DocuDevsClient:
 
             await asyncio.sleep(poll_interval)
 
-        # When completed, fetch the result once
+        # When completed, fetch in desired format
+        if result_format == "json":
+            return await self.result_json(guid)
+        if result_format == "csv":
+            return await self.result_csv(guid)
+        if result_format == "excel":
+            return await self.result_excel(guid, save_to=excel_save_to)
+
+        # Legacy fetch
         result_response = await self.result(uuid=guid)
         if result_response.status_code == HTTPStatus.OK:
             parsed = result_response.parsed
